==> range-1.0.9-alpha.2.tgz: package/lib/index.js <==
var Range = (function () {
    'use strict';

    function noop() { }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function is_empty(obj) {
        return Object.keys(obj).length === 0;
    }
    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        node.parentNode.removeChild(node);
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_style(node, key, value, important) {
        node.style.setProperty(key, value, important ? 'important' : '');
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }

    const dirty_components = [];
    const binding_callbacks = [];
    const render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    let flushing = false;
    const seen_callbacks = new Set();
    function flush() {
        if (flushing)
            return;
        flushing = true;
        do {
            // first, call beforeUpdate functions
            // and update components
            for (let i = 0; i < dirty_components.length; i += 1) {
                const component = dirty_components[i];
                set_current_component(component);
                update(component.$$);
            }
            set_current_component(null);
            dirty_components.length = 0;
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                    callback();
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
        flushing = false;
        seen_callbacks.clear();
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    const outroing = new Set();
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function mount_component(component, target, anchor, customElement) {
        const { fragment, on_mount, on_destroy, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        if (!customElement) {
            // onMount happens before the initial afterUpdate
            add_render_callback(() => {
                const new_on_destroy = on_mount.map(run).filter(is_function);
                if (on_destroy) {
                    on_destroy.push(...new_on_destroy);
                }
                else {
                    // Edge case - component was destroyed immediately,
                    // most likely as a result of a binding initialising
                    run_all(new_on_destroy);
                }
                component.$$.on_mount = [];
            });
        }
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const $$ = component.$$ = {
            fragment: null,
            ctx: null,
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            on_disconnect: [],
            before_update: [],
            after_update: [],
            context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
            // everything else
            callbacks: blank_object(),
            dirty,
            skip_bound: false,
            root: options.target || parent_component.$$.root
        };
        append_styles && append_styles($$.root);
        let ready = false;
        $$.ctx = instance
            ? instance(component, options.props || {}, (i, ret, ...rest) => {
                const value = rest.length ? rest[0] : ret;
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if (!$$.skip_bound && $$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                const nodes = children(options.target);
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(nodes);
                nodes.forEach(detach);
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor, options.customElement);
            flush();
        }
        set_current_component(parent_component);
    }
    /**
     * Base class for Svelte components. Used when dev=false.
     */
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set($$props) {
            if (this.$$set && !is_empty($$props)) {
                this.$$.skip_bound = true;
                this.$$set($$props);
                this.$$.skip_bound = false;
            }
        }
    }

    /* components/range/src/Range.svelte generated by Svelte v3.44.2 */

    function create_fragment(ctx) {
    	let div1;
    	let input0;
    	let t0;
    	let input1;
    	let t1;
    	let div0;
    	let mounted;
    	let dispose;

    	return {
    		c() {
    			div1 = element("div");
    			input0 = element("input");
    			t0 = space();
    			input1 = element("input");
    			t1 = space();
    			div0 = element("div");
    			attr(input0, "id", "lower");
    			attr(input0, "type", "range");
    			attr(input0, "min", /*min*/ ctx[0]);
    			attr(input0, "max", /*max*/ ctx[1]);
    			input0.value = /*min*/ ctx[0];
    			attr(input0, "class", "svelte-zydm2h");
    			attr(input1, "id", "upper");
    			attr(input1, "type", "range");
    			attr(input1, "min", /*min*/ ctx[0]);
    			attr(input1, "max", /*max*/ ctx[1]);
    			input1.value = /*max*/ ctx[1];
    			attr(input1, "class", "svelte-zydm2h");
    			attr(div0, "class", "ink-bar svelte-zydm2h");
    			set_style(div0, "position", "absolute");
    			attr(div1, "class", "resp__multi-range svelte-zydm2h");
    		},
    		m(target, anchor) {
    			insert(target, div1, anchor);
    			append(div1, input0);
    			/*input0_binding*/ ctx[9](input0);
    			append(div1, t0);
    			append(div1, input1);
    			/*input1_binding*/ ctx[10](input1);
    			append(div1, t1);
    			append(div1, div0);
    			/*div0_binding*/ ctx[11](div0);

    			if (!mounted) {
    				dispose = [
    					listen(input0, "input", /*onLowerSlide*/ ctx[5]),
    					listen(input1, "input", /*onUpperSlide*/ ctx[6])
    				];

    				mounted = true;
    			}
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*min*/ 1) {
    				attr(input0, "min", /*min*/ ctx[0]);
    			}

    			if (dirty & /*max*/ 2) {
    				attr(input0, "max", /*max*/ ctx[1]);
    			}

    			if (dirty & /*min*/ 1) {
    				input0.value = /*min*/ ctx[0];
    			}

    			if (dirty & /*min*/ 1) {
    				attr(input1, "min", /*min*/ ctx[0]);
    			}

    			if (dirty & /*max*/ 2) {
    				attr(input1, "max", /*max*/ ctx[1]);
    			}

    			if (dirty & /*max*/ 2) {
    				input1.value = /*max*/ ctx[1];
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(div1);
    			/*input0_binding*/ ctx[9](null);
    			/*input1_binding*/ ctx[10](null);
    			/*div0_binding*/ ctx[11](null);
    			mounted = false;
    			run_all(dispose);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let { min = "1" } = $$props;
    	let { max = "100" } = $$props;
    	let { lowerVal = min } = $$props;
    	let { upperVal = max } = $$props;
    	let lowerSlider;
    	let upperSlider;
    	let inkBar;

    	const onLowerSlide = () => {
    		let low = parseInt(lowerSlider.value);
    		let up = parseInt(upperSlider.value);
    		$$invalidate(7, lowerVal = lowerSlider.value);

    		if (low >= up - 1) {
    			$$invalidate(2, lowerSlider.value = `${up - 1}`, lowerSlider);
    			$$invalidate(7, lowerVal = `${up - 1}`);
    		}

    		updateInkBar();
    	};

    	const onUpperSlide = e => {
    		let low = parseInt(lowerSlider.value);
    		let up = parseInt(upperSlider.value);
    		$$invalidate(8, upperVal = upperSlider.value);

    		if (up <= low + 1) {
    			$$invalidate(3, upperSlider.value = `${low + 1}`, upperSlider);
    			$$invalidate(8, upperVal = `${low + 1}`);
    		}

    		updateInkBar();
    	};

    	const updateInkBar = () => {
    		let pxPerSlide = lowerSlider.getBoundingClientRect().width / (parseInt(max) - parseInt(min));
    		$$invalidate(4, inkBar.style.left = `${(parseInt(lowerSlider.value) - parseInt(min)) * pxPerSlide}px`, inkBar);
    		$$invalidate(4, inkBar.style.width = `${(parseInt(upperSlider.value) - parseInt(lowerSlider.value)) * pxPerSlide}px`, inkBar);
    	};

    	function input0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			lowerSlider = $$value;
    			$$invalidate(2, lowerSlider);
    		});
    	}

    	function input1_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			upperSlider = $$value;
    			$$invalidate(3, upperSlider);
    		});
    	}

    	function div0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			inkBar = $$value;
    			$$invalidate(4, inkBar);
    		});
    	}

    	$$self.$$set = $$props => {
    		if ('min' in $$props) $$invalidate(0, min = $$props.min);
    		if ('max' in $$props) $$invalidate(1, max = $$props.max);
    		if ('lowerVal' in $$props) $$invalidate(7, lowerVal = $$props.lowerVal);
    		if ('upperVal' in $$props) $$invalidate(8, upperVal = $$props.upperVal);
    	};

    	return [
    		min,
    		max,
    		lowerSlider,
    		upperSlider,
    		inkBar,
    		onLowerSlide,
    		onUpperSlide,
    		lowerVal,
    		upperVal,
    		input0_binding,
    		input1_binding,
    		div0_binding
    	];
    }

    class Range extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance, create_fragment, safe_not_equal, { min: 0, max: 1, lowerVal: 7, upperVal: 8 });
    	}
    }

    return Range;

})();

==> range-1.1.0-alpha.2.tgz: package/lib/index.js <==
var Range = (function () {
    'use strict';

    function noop() { }
    function run(fn) {
        return fn();
    }
    function blank_object() {
        return Object.create(null);
    }
    function run_all(fns) {
        fns.forEach(run);
    }
    function is_function(thing) {
        return typeof thing === 'function';
    }
    function safe_not_equal(a, b) {
        return a != a ? b == b : a !== b || ((a && typeof a === 'object') || typeof a === 'function');
    }
    function is_empty(obj) {
        return Object.keys(obj).length === 0;
    }
    function append(target, node) {
        target.appendChild(node);
    }
    function insert(target, node, anchor) {
        target.insertBefore(node, anchor || null);
    }
    function detach(node) {
        node.parentNode.removeChild(node);
    }
    function element(name) {
        return document.createElement(name);
    }
    function text(data) {
        return document.createTextNode(data);
    }
    function space() {
        return text(' ');
    }
    function listen(node, event, handler, options) {
        node.addEventListener(event, handler, options);
        return () => node.removeEventListener(event, handler, options);
    }
    function attr(node, attribute, value) {
        if (value == null)
            node.removeAttribute(attribute);
        else if (node.getAttribute(attribute) !== value)
            node.setAttribute(attribute, value);
    }
    function children(element) {
        return Array.from(element.childNodes);
    }
    function set_style(node, key, value, important) {
        if (value === null) {
            node.style.removeProperty(key);
        }
        else {
            node.style.setProperty(key, value, important ? 'important' : '');
        }
    }

    let current_component;
    function set_current_component(component) {
        current_component = component;
    }

    const dirty_components = [];
    const binding_callbacks = [];
    const render_callbacks = [];
    const flush_callbacks = [];
    const resolved_promise = Promise.resolve();
    let update_scheduled = false;
    function schedule_update() {
        if (!update_scheduled) {
            update_scheduled = true;
            resolved_promise.then(flush);
        }
    }
    function add_render_callback(fn) {
        render_callbacks.push(fn);
    }
    // flush() calls callbacks in this order:
    // 1. All beforeUpdate callbacks, in order: parents before children
    // 2. All bind:this callbacks, in reverse order: children before parents.
    // 3. All afterUpdate callbacks, in order: parents before children. EXCEPT
    //    for afterUpdates called during the initial onMount, which are called in
    //    reverse order: children before parents.
    // Since callbacks might update component values, which could trigger another
    // call to flush(), the following steps guard against this:
    // 1. During beforeUpdate, any updated components will be added to the
    //    dirty_components array and will cause a reentrant call to flush(). Because
    //    the flush index is kept outside the function, the reentrant call will pick
    //    up where the earlier call left off and go through all dirty components. The
    //    current_component value is saved and restored so that the reentrant call will
    //    not interfere with the "parent" flush() call.
    // 2. bind:this callbacks cannot trigger new flush() calls.
    // 3. During afterUpdate, any updated components will NOT have their afterUpdate
    //    callback called a second time; the seen_callbacks set, outside the flush()
    //    function, guarantees this behavior.
    const seen_callbacks = new Set();
    let flushidx = 0; // Do *not* move this inside the flush() function
    function flush() {
        const saved_component = current_component;
        do {
            // first, call beforeUpdate functions
            // and update components
            while (flushidx < dirty_components.length) {
                const component = dirty_components[flushidx];
                flushidx++;
                set_current_component(component);
                update(component.$$);
            }
            set_current_component(null);
            dirty_components.length = 0;
            flushidx = 0;
            while (binding_callbacks.length)
                binding_callbacks.pop()();
            // then, once components are updated, call
            // afterUpdate functions. This may cause
            // subsequent updates...
            for (let i = 0; i < render_callbacks.length; i += 1) {
                const callback = render_callbacks[i];
                if (!seen_callbacks.has(callback)) {
                    // ...so guard against infinite loops
                    seen_callbacks.add(callback);
                    callback();
                }
            }
            render_callbacks.length = 0;
        } while (dirty_components.length);
        while (flush_callbacks.length) {
            flush_callbacks.pop()();
        }
        update_scheduled = false;
        seen_callbacks.clear();
        set_current_component(saved_component);
    }
    function update($$) {
        if ($$.fragment !== null) {
            $$.update();
            run_all($$.before_update);
            const dirty = $$.dirty;
            $$.dirty = [-1];
            $$.fragment && $$.fragment.p($$.ctx, dirty);
            $$.after_update.forEach(add_render_callback);
        }
    }
    const outroing = new Set();
    function transition_in(block, local) {
        if (block && block.i) {
            outroing.delete(block);
            block.i(local);
        }
    }
    function mount_component(component, target, anchor, customElement) {
        const { fragment, on_mount, on_destroy, after_update } = component.$$;
        fragment && fragment.m(target, anchor);
        if (!customElement) {
            // onMount happens before the initial afterUpdate
            add_render_callback(() => {
                const new_on_destroy = on_mount.map(run).filter(is_function);
                if (on_destroy) {
                    on_destroy.push(...new_on_destroy);
                }
                else {
                    // Edge case - component was destroyed immediately,
                    // most likely as a result of a binding initialising
                    run_all(new_on_destroy);
                }
                component.$$.on_mount = [];
            });
        }
        after_update.forEach(add_render_callback);
    }
    function destroy_component(component, detaching) {
        const $$ = component.$$;
        if ($$.fragment !== null) {
            run_all($$.on_destroy);
            $$.fragment && $$.fragment.d(detaching);
            // TODO null out other refs, including component.$$ (but need to
            // preserve final state?)
            $$.on_destroy = $$.fragment = null;
            $$.ctx = [];
        }
    }
    function make_dirty(component, i) {
        if (component.$$.dirty[0] === -1) {
            dirty_components.push(component);
            schedule_update();
            component.$$.dirty.fill(0);
        }
        component.$$.dirty[(i / 31) | 0] |= (1 << (i % 31));
    }
    function init(component, options, instance, create_fragment, not_equal, props, append_styles, dirty = [-1]) {
        const parent_component = current_component;
        set_current_component(component);
        const $$ = component.$$ = {
            fragment: null,
            ctx: null,
            // state
            props,
            update: noop,
            not_equal,
            bound: blank_object(),
            // lifecycle
            on_mount: [],
            on_destroy: [],
            on_disconnect: [],
            before_update: [],
            after_update: [],
            context: new Map(options.context || (parent_component ? parent_component.$$.context : [])),
            // everything else
            callbacks: blank_object(),
            dirty,
            skip_bound: false,
            root: options.target || parent_component.$$.root
        };
        append_styles && append_styles($$.root);
        let ready = false;
        $$.ctx = instance
            ? instance(component, options.props || {}, (i, ret, ...rest) => {
                const value = rest.length ? rest[0] : ret;
                if ($$.ctx && not_equal($$.ctx[i], $$.ctx[i] = value)) {
                    if (!$$.skip_bound && $$.bound[i])
                        $$.bound[i](value);
                    if (ready)
                        make_dirty(component, i);
                }
                return ret;
            })
            : [];
        $$.update();
        ready = true;
        run_all($$.before_update);
        // `false` as a special case of no DOM component
        $$.fragment = create_fragment ? create_fragment($$.ctx) : false;
        if (options.target) {
            if (options.hydrate) {
                const nodes = children(options.target);
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.l(nodes);
                nodes.forEach(detach);
            }
            else {
                // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                $$.fragment && $$.fragment.c();
            }
            if (options.intro)
                transition_in(component.$$.fragment);
            mount_component(component, options.target, options.anchor, options.customElement);
            flush();
        }
        set_current_component(parent_component);
    }
    /**
     * Base class for Svelte components. Used when dev=false.
     */
    class SvelteComponent {
        $destroy() {
            destroy_component(this, 1);
            this.$destroy = noop;
        }
        $on(type, callback) {
            const callbacks = (this.$$.callbacks[type] || (this.$$.callbacks[type] = []));
            callbacks.push(callback);
            return () => {
                const index = callbacks.indexOf(callback);
                if (index !== -1)
                    callbacks.splice(index, 1);
            };
        }
        $set($$props) {
            if (this.$$set && !is_empty($$props)) {
                this.$$.skip_bound = true;
                this.$$set($$props);
                this.$$.skip_bound = false;
            }
        }
    }

    /* components/range/src/Range.svelte generated by Svelte v3.46.2 */

    function create_fragment(ctx) {
    	let div1;
    	let input0;
    	let t0;
    	let input1;
    	let t1;
    	let div0;
    	let mounted;
    	let dispose;

    	return {
    		c() {
    			div1 = element("div");
    			input0 = element("input");
    			t0 = space();
    			input1 = element("input");
    			t1 = space();
    			div0 = element("div");
    			attr(input0, "id", "lower");
    			attr(input0, "type", "range");
    			attr(input0, "min", /*min*/ ctx[0]);
    			attr(input0, "max", /*max*/ ctx[1]);
    			input0.value = /*min*/ ctx[0];
    			attr(input0, "class", "svelte-zydm2h");
    			attr(input1, "id", "upper");
    			attr(input1, "type", "range");
    			attr(input1, "min", /*min*/ ctx[0]);
    			attr(input1, "max", /*max*/ ctx[1]);
    			input1.value = /*max*/ ctx[1];
    			attr(input1, "class", "svelte-zydm2h");
    			attr(div0, "class", "ink-bar svelte-zydm2h");
    			set_style(div0, "position", "absolute");
    			attr(div1, "class", "resp__multi-range svelte-zydm2h");
    		},
    		m(target, anchor) {
    			insert(target, div1, anchor);
    			append(div1, input0);
    			/*input0_binding*/ ctx[9](input0);
    			append(div1, t0);
    			append(div1, input1);
    			/*input1_binding*/ ctx[10](input1);
    			append(div1, t1);
    			append(div1, div0);
    			/*div0_binding*/ ctx[11](div0);

    			if (!mounted) {
    				dispose = [
    					listen(input0, "input", /*onLowerSlide*/ ctx[5]),
    					listen(input1, "input", /*onUpperSlide*/ ctx[6])
    				];

    				mounted = true;
    			}
    		},
    		p(ctx, [dirty]) {
    			if (dirty & /*min*/ 1) {
    				attr(input0, "min", /*min*/ ctx[0]);
    			}

    			if (dirty & /*max*/ 2) {
    				attr(input0, "max", /*max*/ ctx[1]);
    			}

    			if (dirty & /*min*/ 1) {
    				input0.value = /*min*/ ctx[0];
    			}

    			if (dirty & /*min*/ 1) {
    				attr(input1, "min", /*min*/ ctx[0]);
    			}

    			if (dirty & /*max*/ 2) {
    				attr(input1, "max", /*max*/ ctx[1]);
    			}

    			if (dirty & /*max*/ 2) {
    				input1.value = /*max*/ ctx[1];
    			}
    		},
    		i: noop,
    		o: noop,
    		d(detaching) {
    			if (detaching) detach(div1);
    			/*input0_binding*/ ctx[9](null);
    			/*input1_binding*/ ctx[10](null);
    			/*div0_binding*/ ctx[11](null);
    			mounted = false;
    			run_all(dispose);
    		}
    	};
    }

    function instance($$self, $$props, $$invalidate) {
    	let { min = "1" } = $$props;
    	let { max = "100" } = $$props;
    	let { lowerVal = min } = $$props;
    	let { upperVal = max } = $$props;
    	let lowerSlider;
    	let upperSlider;
    	let inkBar;

    	const onLowerSlide = () => {
    		let low = parseInt(lowerSlider.value);
    		let up = parseInt(upperSlider.value);
    		$$invalidate(7, lowerVal = lowerSlider.value);

    		if (low >= up - 1) {
    			$$invalidate(2, lowerSlider.value = `${up - 1}`, lowerSlider);
    			$$invalidate(7, lowerVal = `${up - 1}`);
    		}

    		updateInkBar();
    	};

    	const onUpperSlide = e => {
    		let low = parseInt(lowerSlider.value);
    		let up = parseInt(upperSlider.value);
    		$$invalidate(8, upperVal = upperSlider.value);

    		if (up <= low + 1) {
    			$$invalidate(3, upperSlider.value = `${low + 1}`, upperSlider);
    			$$invalidate(8, upperVal = `${low + 1}`);
    		}

    		updateInkBar();
    	};

    	const updateInkBar = () => {
    		let pxPerSlide = lowerSlider.getBoundingClientRect().width / (parseInt(max) - parseInt(min));
    		$$invalidate(4, inkBar.style.left = `${(parseInt(lowerSlider.value) - parseInt(min)) * pxPerSlide}px`, inkBar);
    		$$invalidate(4, inkBar.style.width = `${(parseInt(upperSlider.value) - parseInt(lowerSlider.value)) * pxPerSlide}px`, inkBar);
    	};

    	function input0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			lowerSlider = $$value;
    			$$invalidate(2, lowerSlider);
    		});
    	}

    	function input1_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			upperSlider = $$value;
    			$$invalidate(3, upperSlider);
    		});
    	}

    	function div0_binding($$value) {
    		binding_callbacks[$$value ? 'unshift' : 'push'](() => {
    			inkBar = $$value;
    			$$invalidate(4, inkBar);
    		});
    	}

    	$$self.$$set = $$props => {
    		if ('min' in $$props) $$invalidate(0, min = $$props.min);
    		if ('max' in $$props) $$invalidate(1, max = $$props.max);
    		if ('lowerVal' in $$props) $$invalidate(7, lowerVal = $$props.lowerVal);
    		if ('upperVal' in $$props) $$invalidate(8, upperVal = $$props.upperVal);
    	};

    	return [
    		min,
    		max,
    		lowerSlider,
    		upperSlider,
    		inkBar,
    		onLowerSlide,
    		onUpperSlide,
    		lowerVal,
    		upperVal,
    		input0_binding,
    		input1_binding,
    		div0_binding
    	];
    }

    class Range extends SvelteComponent {
    	constructor(options) {
    		super();
    		init(this, options, instance, create_fragment, safe_not_equal, { min: 0, max: 1, lowerVal: 7, upperVal: 8 });
    	}
    }

    return Range;

})();
